@@ -65,7 +65,7 @@ def cli(ctx, config, project_name, path):
     ctx.obj['project_name'] = os.path.basename(path.strip('/')) if project_name is None else project_name
 
     ctx.obj['client'] = get_client(config.get('client', {}))
-    ctx.obj.update(git.get_tag())
+    ctx.obj.update(git.get_tag(prefix=config.get('client', {}).get('prefix', '')))
 
 
 def get_client(client):
