@@ -1,4 +1,4 @@
-import pathlib
+import os
 import tempfile
 from unittest import mock
 
@@ -13,7 +13,7 @@ def test_render(runner, tag):
         result = runner.invoke(cli, ['render', f'--dockerfile={tmpfile.name}'])
         assert result.exit_code == 0
         with open(tmpfile.name, 'r') as fh_:
-            assert fh_.readline() == 'FROM python:slim\n'
+            assert fh_.readline() == 'FROM docker.io/python:slim\n'
             assert fh_.readline() == 'ENV PYTHON=True\n'
             assert fh_.readline() == 'WORKDIR /srv\n'
             assert fh_.readline() == '\n'
@@ -21,6 +21,13 @@ def test_render(runner, tag):
             assert tag['commit'] in fh_.readline()
 
 
+def test_render_with_env_var_override(runner):
+    with tempfile.NamedTemporaryFile() as tmpfile:
+        with mock.patch.dict(os.environ, {'GIT_BRANCH': 'other'}):
+            result = runner.invoke(cli, ['render', f'--dockerfile={tmpfile.name}'])
+            assert result.exit_code == 0
+
+
 def test_render_isolated(runner):
     with open('Dockerfile.j2') as fh_, runner.isolated_filesystem() as th_:
 
@@ -30,7 +37,7 @@ def test_render_isolated(runner):
         result = runner.invoke(cli, [f'--path={th_}', 'render'])
         assert result.exit_code == 0
         with open('Dockerfile', 'r') as fh_:
-            assert fh_.readline() == 'FROM python:slim\n'
+            assert fh_.readline() == 'FROM docker.io/python:slim\n'
             assert fh_.readline() == 'ENV PYTHON=True\n'
             assert fh_.readline() == 'WORKDIR /srv\n'
             assert not fh_.readline()
@@ -41,7 +48,7 @@ def test_container_start_no_tests(runner, attrs):
     client.containers.get.return_value.attrs = attrs
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['start', '-n'])
-    assert client.containers.get.call_count == 2
+    assert client.containers.get.call_count == 4
     assert client.containers.run.called is False
     assert result.exit_code == 0
 
@@ -63,7 +70,7 @@ def test_container_start_with_tests(runner, attrs):
     client.images.get.return_value.id = client.containers.get.return_value.image.id
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['start'])
-    assert client.containers.get.call_count == 6
+    assert client.containers.get.call_count == 11
     assert client.containers.run.called is False
     assert result.exit_code == 0
 
@@ -73,7 +80,7 @@ def test_container_start_with_tests_old_image(runner, attrs):
     client.containers.get.return_value.attrs = attrs
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['start'])
-    assert client.containers.get.call_count == 7
+    assert client.containers.get.call_count == 11
     assert client.containers.run.called is True
     assert client.containers.get.return_value.stop.called is True
     assert client.containers.get.return_value.wait.called is True
@@ -122,7 +129,14 @@ def test_container_build(runner, build_output):
     client.api.build.return_value = build_output
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['build', '--tag=blah'])
-    client.api.build.assert_called_with(path='.', dockerfile='Dockerfile', tag='blah', nocache=False, rm=True)
+    client.api.build.assert_called_with(
+        path='.',
+        dockerfile='Dockerfile',
+        tag='blah',
+        nocache=False,
+        rm=True,
+        decode=True,
+    )
     assert result.exit_code == 0
 
 
@@ -130,13 +144,12 @@ def test_container_start_with_tests_without_image(runner, attrs):
     client = mock.MagicMock()
     client.containers.get.return_value.attrs = attrs
     image = mock.MagicMock()
-    client.images.get.side_effect = [ImageNotFound('image not found'), image, image]
+    client.images.get.side_effect = [ImageNotFound('image not found'), image, image, image]
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['start'])
-    print(result.output)
-    assert client.containers.get.call_count == 7
+    assert client.containers.get.call_count == 11
     assert client.containers.run.called is True
-    assert client.images.get.call_count == 3
+    assert client.images.get.call_count == 4
     assert result.exit_code == 0
 
 
@@ -151,7 +164,7 @@ def test_container_run(runner, attrs):
     ]
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['run'])
-    assert client.containers.get.call_count == 9
+    assert client.containers.get.call_count == 14
     assert client.containers.run.called is False
     assert result.exit_code == 0
     assert 'foobarbaz' in result.output
@@ -169,7 +182,7 @@ def test_container_run_step(runner, attrs):
     ]
     with mock.patch('docker.from_env', return_value=client):
         result = runner.invoke(cli, ['run', '--step=install'])
-    assert client.containers.get.call_count == 8
+    assert client.containers.get.call_count == 13
     assert client.containers.run.called is False
     assert result.exit_code == 0
     assert 'foobarbaz' in result.output
